/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package org.apache.isis.viewer.xhtml.viewer.resources.objects;

import org.apache.isis.core.commons.authentication.AuthenticationSession;
import org.apache.isis.core.metamodel.adapter.ObjectAdapter;
import org.apache.isis.core.metamodel.spec.feature.ObjectMember;
import org.apache.isis.viewer.xhtml.viewer.html.HtmlClass;
import org.apache.isis.viewer.xhtml.viewer.tree.Element;
import org.apache.isis.viewer.xhtml.viewer.xom.ResourceContext;

public abstract class TableColumnNakedObjectMemberInvalidReason<T extends ObjectMember> extends
    TableColumnNakedObjectMember<T> {

    public TableColumnNakedObjectMemberInvalidReason(final AuthenticationSession session,
        final ObjectAdapter nakedObject, final ResourceContext resourceContext) {
        super("Invalid Reason", session, nakedObject, resourceContext);
    }

    /**
     * Creates a &lt;p id=&quot;association-invalid-<i>associationId</i>&quot;/&gt; element so that Javascript code can
     * populate during validation.
     */
    @Override
    public Element doTd(final T member) {
        return builder().el("p").classAttr(HtmlClass.VALID).idAttr(getDomId(member)).build();
    }

    protected abstract String getDomId(T member);

}
